Improve this doc View Source

Finds links in text input and turns them into html links. Supports http/https/ftp/mailto and plain email address links.

Requires the `ngSanitize` module to be installed.

## Usage

### In HTML Template Binding

`<span ng-bind-html="linky_expression | linky"></span>`

### In JavaScript

    $filter('linky')(text, target)

### Arguments

Param | Type | Details
--- | --- | ---
text | string | Input text.
target | string | Window (_blank|_self|_parent|_top) or named frame to open links in.

### Returns

string | Html-linkified text.

## Example

Edit in Plunker

    <script>
      angular.module('linkyExample', ['ngSanitize'])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.snippet =
            'Pretty text with some links:\n'+
            'http://angularjs.org/,\n'+
            'mailto:us@somewhere.org,\n'+
            'another@somewhere.org,\n'+
            'and one more: ftp://127.0.0.1/.';
          $scope.snippetWithTarget = 'http://angularjs.org/';
        }]);
    </script>
    <div ng-controller="ExampleController">
    Snippet: <textarea ng-model="snippet" cols="60" rows="3"></textarea>
    <table>
      <tr>
        <td>Filter</td>
        <td>Source</td>
        <td>Rendered</td>
      </tr>
      <tr id="linky-filter">
        <td>linky filter</td>
        <td>
          <pre><div ng-bind-html="snippet | linky"><br></div></pre>
        </td>
        <td>
          <div ng-bind-html="snippet | linky"></div>
        </td>
      </tr>
      <tr id="linky-target">
       <td>linky target</td>
       <td>
         <pre><div ng-bind-html="snippetWithTarget | linky:'_blank'"><br></div></pre>
       </td>
       <td>
         <div ng-bind-html="snippetWithTarget | linky:'_blank'"></div>
       </td>
      </tr>
      <tr id="escaped-html">
        <td>no filter</td>
        <td><pre><div ng-bind="snippet"><br></div></pre></td>
        <td><div ng-bind="snippet"></div></td>
      </tr>
    </table>

    it('should linkify the snippet with urls', function() {
      expect(element(by.id('linky-filter')).element(by.binding('snippet | linky')).getText()).
          toBe('Pretty text with some links: http://angularjs.org/, us@somewhere.org, ' +
               'another@somewhere.org, and one more: ftp://127.0.0.1/.');
      expect(element.all(by.css('#linky-filter a')).count()).toEqual(4);
    });

    it('should not linkify snippet without the linky filter', function() {
      expect(element(by.id('escaped-html')).element(by.binding('snippet')).getText()).
          toBe('Pretty text with some links: http://angularjs.org/, mailto:us@somewhere.org, ' +
               'another@somewhere.org, and one more: ftp://127.0.0.1/.');
      expect(element.all(by.css('#escaped-html a')).count()).toEqual(0);
    });

    it('should update', function() {
      element(by.model('snippet')).clear();
      element(by.model('snippet')).sendKeys('new http://link.');
      expect(element(by.id('linky-filter')).element(by.binding('snippet | linky')).getText()).
          toBe('new http://link.');
      expect(element.all(by.css('#linky-filter a')).count()).toEqual(1);
      expect(element(by.id('escaped-html')).element(by.binding('snippet')).getText())
          .toBe('new http://link.');
    });

    it('should work with the target property', function() {
     expect(element(by.id('linky-target')).
         element(by.binding("snippetWithTarget | linky:'_blank'")).getText()).
         toBe('http://angularjs.org/');
     expect(element(by.css('#linky-target a')).getAttribute('target')).toEqual('_blank');
    });